@@ -9,7 +9,7 @@ import time
 from motordecalidad.rules import *
 
 
-print("Motor de Calidad Version Release 1.7.21")
+print("Motor de Calidad Version Release 1.8.7")
 
 # Main function, Invokes all the parameters from the json, Optionally filters, starts the rule validation
 # Writes and returns the summary of the validation 
@@ -515,10 +515,9 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
         dataDateWidget = dataDate
     try:
         emailData = validationData.groupBy("CARACTERISTICA_REGLA").mean("PORCENTAJE_CALIDAD_OK")
-        if sendEmail == "YES":
-            send_email(registerAmount,rulesNumber,output.get(JsonParts.Path),emailData,email)
+        send_email(registerAmount,rulesNumber,output.get(JsonParts.Path),emailData,email)
     except:
-        print("Se omite el envio de correo")
+        print("Se omite el envío de correo")
     return validationData.select(
         DataDate.value(lit(dataDateWidget)),
         CountryId.value(lit(pais_widget.upper())),
